==> zio-aws-chimesdkmessaging_2.13-5.17.158.4-sources.jar: zio/aws/chimesdkmessaging/model/ChannelModerator.scala <==
package zio.aws.chimesdkmessaging.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import java.time.Instant
import zio.aws.chimesdkmessaging.model.primitives.{Timestamp, ChimeArn}
import scala.jdk.CollectionConverters._
final case class ChannelModerator(
    moderator: Option[zio.aws.chimesdkmessaging.model.Identity] = None,
    channelArn: Option[ChimeArn] = None,
    createdTimestamp: Option[Timestamp] = None,
    createdBy: Option[zio.aws.chimesdkmessaging.model.Identity] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.chimesdkmessaging.model.ChannelModerator = {
    import ChannelModerator.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.chimesdkmessaging.model.ChannelModerator
      .builder()
      .optionallyWith(moderator.map(value => value.buildAwsValue()))(
        _.moderator
      )
      .optionallyWith(
        channelArn.map(value => ChimeArn.unwrap(value): java.lang.String)
      )(_.channelArn)
      .optionallyWith(
        createdTimestamp.map(value => Timestamp.unwrap(value): Instant)
      )(_.createdTimestamp)
      .optionallyWith(createdBy.map(value => value.buildAwsValue()))(
        _.createdBy
      )
      .build()
  }
  def asReadOnly: zio.aws.chimesdkmessaging.model.ChannelModerator.ReadOnly =
    zio.aws.chimesdkmessaging.model.ChannelModerator.wrap(buildAwsValue())
}
object ChannelModerator {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.chimesdkmessaging.model.ChannelModerator
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.chimesdkmessaging.model.ChannelModerator =
      zio.aws.chimesdkmessaging.model.ChannelModerator(
        moderator.map(value => value.asEditable),
        channelArn.map(value => value),
        createdTimestamp.map(value => value),
        createdBy.map(value => value.asEditable)
      )
    def moderator: Option[zio.aws.chimesdkmessaging.model.Identity.ReadOnly]
    def channelArn: Option[ChimeArn]
    def createdTimestamp: Option[Timestamp]
    def createdBy: Option[zio.aws.chimesdkmessaging.model.Identity.ReadOnly]
    def getModerator: ZIO[
      Any,
      AwsError,
      zio.aws.chimesdkmessaging.model.Identity.ReadOnly
    ] = AwsError.unwrapOptionField("moderator", moderator)
    def getChannelArn: ZIO[Any, AwsError, ChimeArn] =
      AwsError.unwrapOptionField("channelArn", channelArn)
    def getCreatedTimestamp: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("createdTimestamp", createdTimestamp)
    def getCreatedBy: ZIO[
      Any,
      AwsError,
      zio.aws.chimesdkmessaging.model.Identity.ReadOnly
    ] = AwsError.unwrapOptionField("createdBy", createdBy)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.chimesdkmessaging.model.ChannelModerator
  ) extends zio.aws.chimesdkmessaging.model.ChannelModerator.ReadOnly {
    override val moderator
        : Option[zio.aws.chimesdkmessaging.model.Identity.ReadOnly] = scala
      .Option(impl.moderator())
      .map(value => zio.aws.chimesdkmessaging.model.Identity.wrap(value))
    override val channelArn: Option[ChimeArn] = scala
      .Option(impl.channelArn())
      .map(value => zio.aws.chimesdkmessaging.model.primitives.ChimeArn(value))
    override val createdTimestamp: Option[Timestamp] = scala
      .Option(impl.createdTimestamp())
      .map(value => zio.aws.chimesdkmessaging.model.primitives.Timestamp(value))
    override val createdBy
        : Option[zio.aws.chimesdkmessaging.model.Identity.ReadOnly] = scala
      .Option(impl.createdBy())
      .map(value => zio.aws.chimesdkmessaging.model.Identity.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.chimesdkmessaging.model.ChannelModerator
  ): zio.aws.chimesdkmessaging.model.ChannelModerator.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-chimesdkmessaging_2.13-5.17.195.2-sources.jar: zio/aws/chimesdkmessaging/model/ChannelModerator.scala <==
package zio.aws.chimesdkmessaging.model
import zio.aws.chimesdkmessaging.model.primitives.{Timestamp, ChimeArn}
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import scala.jdk.CollectionConverters._
final case class ChannelModerator(
    moderator: Optional[zio.aws.chimesdkmessaging.model.Identity] =
      Optional.Absent,
    channelArn: Optional[ChimeArn] = Optional.Absent,
    createdTimestamp: Optional[Timestamp] = Optional.Absent,
    createdBy: Optional[zio.aws.chimesdkmessaging.model.Identity] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.chimesdkmessaging.model.ChannelModerator = {
    import ChannelModerator.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.chimesdkmessaging.model.ChannelModerator
      .builder()
      .optionallyWith(moderator.map(value => value.buildAwsValue()))(
        _.moderator
      )
      .optionallyWith(
        channelArn.map(value => ChimeArn.unwrap(value): java.lang.String)
      )(_.channelArn)
      .optionallyWith(
        createdTimestamp.map(value => Timestamp.unwrap(value): Instant)
      )(_.createdTimestamp)
      .optionallyWith(createdBy.map(value => value.buildAwsValue()))(
        _.createdBy
      )
      .build()
  }
  def asReadOnly: zio.aws.chimesdkmessaging.model.ChannelModerator.ReadOnly =
    zio.aws.chimesdkmessaging.model.ChannelModerator.wrap(buildAwsValue())
}
object ChannelModerator {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.chimesdkmessaging.model.ChannelModerator
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.chimesdkmessaging.model.ChannelModerator =
      zio.aws.chimesdkmessaging.model.ChannelModerator(
        moderator.map(value => value.asEditable),
        channelArn.map(value => value),
        createdTimestamp.map(value => value),
        createdBy.map(value => value.asEditable)
      )
    def moderator: Optional[zio.aws.chimesdkmessaging.model.Identity.ReadOnly]
    def channelArn: Optional[ChimeArn]
    def createdTimestamp: Optional[Timestamp]
    def createdBy: Optional[zio.aws.chimesdkmessaging.model.Identity.ReadOnly]
    def getModerator: ZIO[
      Any,
      AwsError,
      zio.aws.chimesdkmessaging.model.Identity.ReadOnly
    ] = AwsError.unwrapOptionField("moderator", moderator)
    def getChannelArn: ZIO[Any, AwsError, ChimeArn] =
      AwsError.unwrapOptionField("channelArn", channelArn)
    def getCreatedTimestamp: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("createdTimestamp", createdTimestamp)
    def getCreatedBy: ZIO[
      Any,
      AwsError,
      zio.aws.chimesdkmessaging.model.Identity.ReadOnly
    ] = AwsError.unwrapOptionField("createdBy", createdBy)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.chimesdkmessaging.model.ChannelModerator
  ) extends zio.aws.chimesdkmessaging.model.ChannelModerator.ReadOnly {
    override val moderator
        : Optional[zio.aws.chimesdkmessaging.model.Identity.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.moderator())
        .map(value => zio.aws.chimesdkmessaging.model.Identity.wrap(value))
    override val channelArn: Optional[ChimeArn] = zio.aws.core.internal
      .optionalFromNullable(impl.channelArn())
      .map(value => zio.aws.chimesdkmessaging.model.primitives.ChimeArn(value))
    override val createdTimestamp: Optional[Timestamp] = zio.aws.core.internal
      .optionalFromNullable(impl.createdTimestamp())
      .map(value => zio.aws.chimesdkmessaging.model.primitives.Timestamp(value))
    override val createdBy
        : Optional[zio.aws.chimesdkmessaging.model.Identity.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.createdBy())
        .map(value => zio.aws.chimesdkmessaging.model.Identity.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.chimesdkmessaging.model.ChannelModerator
  ): zio.aws.chimesdkmessaging.model.ChannelModerator.ReadOnly = new Wrapper(
    impl
  )
}
